package cn.com.ctop.job.live.handler;

import cn.com.ctop.job.live.service.AgentTokenService;
import cn.com.ctop.job.live.service.IKuaishouLiveAccountReportDailyService;
import cn.com.ctop.job.live.utils.Check;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

@Slf4j
@Component
public class AdAccountReportJob {

    @Autowired
    private IKuaishouLiveAccountReportDailyService accountReportDailyService;

    @Autowired
    private AgentTokenService tokenService;

    private static ExecutorService dailyExecutorService = Executors.newFixedThreadPool(3);
    private static ExecutorService hourExecutorService = Executors.newFixedThreadPool(3);

    /**
     * 获取广告账户信息
     * 前1天
     *
     * @throws Exception
     */
    @XxlJob("AdAccountReportJob")
    public void adAccountReportJob() {
        String param = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(param)) {
            log.error("入参为空");
            return;
        }
        String token = tokenService.getByAccountId(Long.valueOf(param));
        if (Check.isNull(token)) {
            log.error("此账户未获取到相关token，accountId：{}", param);
            return;
        }

        dailyExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        try {
                            accountReportDailyService.getKuaishouAccountReport(Long.valueOf(param), token);
                        } catch (Exception e) {
                            log.info(String.valueOf(e));
                            ;
                        }
                    }
                });
    }

     /**
     * 获取广告账户信息（时报）
     */
    @XxlJob("AdAccountHourReportJob")
    public void adAccountHourReportJob() {
        String param = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(param)) {
            log.error("入参为空");
            return;
        }
        String token = tokenService.getByAccountId(Long.valueOf(param));
        if (Check.isNull(token)) {
            log.error("此账户未获取到相关token，accountId：{}", param);
            return;
        }

        hourExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        try {
                            accountReportDailyService.getKuaishouAccountHourReport(Long.valueOf(param), token);
                        } catch (Exception e) {
                            log.info(String.valueOf(e));
                            ;
                        }
                    }
                });
    }


}
