package cn.com.ctop.job.live.handler;

import cn.com.ctop.job.live.service.AgentTokenService;
import cn.com.ctop.job.live.service.IKuaishouLiveUnitListService;
import cn.com.ctop.job.live.service.IKuaishouLiveUnitReportDailyService;
import cn.com.ctop.job.live.utils.Check;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

@Slf4j
@Component
public class AdUnitReportJob {

    @Autowired
    private AgentTokenService tokenService;

    @Autowired
    private IKuaishouLiveUnitReportDailyService unitReportDailyService;

    @Autowired
    private IKuaishouLiveUnitListService unitListService;

    private static ExecutorService dailyExecutorService = Executors.newFixedThreadPool(3);
    private static ExecutorService hourExecutorService = Executors.newFixedThreadPool(3);
    private static ExecutorService liveExecutorService = Executors.newFixedThreadPool(3);

    /**
     * 获取广告组信息
     * 前1天
     *
     * @throws Exception
     */
    @XxlJob("AdUnitReportJob")
    public void AdUnitListReportJob() {
        String param = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(param)) {
            log.error("入参为空");
            return;
        }
        String token = tokenService.getByAccountId(Long.valueOf(param));
        if (Check.isNull(token)) {
            log.error("此账户未获取到相关token，accountId：{}", param);
            return;
        }

        dailyExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        try {
                            unitReportDailyService.getKuaishouUnitReport(Long.valueOf(param), token, 1);
                        } catch (Exception e) {
                            log.info(String.valueOf(e));
                        }
                    }
                });
    }

    /**
     * 获取广告组信息（时报）
     */
    @XxlJob("AdUnitHourReportJob")
    public void adUnitHourReportJob() {
        String param = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(param)) {
            log.error("入参为空");
            return;
        }
        String token = tokenService.getByAccountId(Long.valueOf(param));
        if (Check.isNull(token)) {
            log.error("此账户未获取到相关token，accountId：{}", param);
            return;
        }

        hourExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        try {
                            unitReportDailyService.getKuaishouUnitHourReport(Long.valueOf(param), token, 1);
                        } catch (Exception e) {
                            log.info(String.valueOf(e));
                        }
                    }
                });
    }


    /**
     * 获取广告组信息（时报）
     */
    @XxlJob("getKuaishouUnit")
    public void getKuaishouUnit() {
        String param = XxlJobHelper.getJobParam(); // 执行参数
        if (Check.isNull(param)) {
            log.error("入参为空");
            return;
        }
        String token = tokenService.getByAccountId(Long.valueOf(param));
        if (Check.isNull(token)) {
            log.error("此账户未获取到相关token，accountId：{}", param);
            return;
        }

        liveExecutorService.submit(
                new Runnable() {
                    @Override
                    public void run() {
                        try {
                            unitListService.getKuaishouUnit(Long.valueOf(param), token);
                        } catch (Exception e) {
                            log.info(String.valueOf(e));
                        }
                    }
                });
    }

}
