package cn.com.ctop.job.live.service.impl;

import cn.com.ctop.job.live.entity.KuaishouLiveCreativeList;
import cn.com.ctop.job.live.entity.KuaishouLiveUnitList;
import cn.com.ctop.job.live.mapper.KuaishouLiveCreativeListMapper;
import cn.com.ctop.job.live.service.IKuaishouLiveCreativeListService;
import cn.com.ctop.job.live.utils.APIUtil;
import cn.com.ctop.job.live.utils.Check;
import cn.com.ctop.job.live.utils.DateUtils;
import cn.com.ctop.job.live.utils.KuaishouAPIConstant;
import cn.com.ctop.job.live.utils.Result;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 创意Service业务层处理
 *
 * @author ruoyi
 * @date 2022-07-28
 */
@Slf4j
@Service
public class KuaishouLiveCreativeListServiceImpl implements IKuaishouLiveCreativeListService {
    @Autowired
    private KuaishouLiveCreativeListMapper mapper;

    /**
     * 查询创意
     *
     * @param accountId 创意主键
     * @return 创意
     */
    @Override
    public KuaishouLiveCreativeList selectKuaishouLiveCreativeListByAccountId(Long accountId) {
        return mapper.selectKuaishouLiveCreativeListByAccountId(accountId);
    }

    /**
     * 查询创意列表
     *
     * @param kuaishouLiveCreativeList 创意
     * @return 创意
     */
    @Override
    public List<KuaishouLiveCreativeList> selectKuaishouLiveCreativeListList(KuaishouLiveCreativeList kuaishouLiveCreativeList) {
        return mapper.selectKuaishouLiveCreativeListList(kuaishouLiveCreativeList);
    }

    @Override
    public Result<Object> getKuaishouCreative(Long accountId, String token) {
        log.info("调用接口---getKuaishouAccountReport(获取直播账户报表)---账户:{}", accountId);
        Result<Object> result = new Result<>();
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("advertiser_id", accountId);
        JSONObject params = new JSONObject();
        params.put("start_time", DateUtils.timeToStamp(DateUtils.getDate() + " 00:00:00"));
        params.put("end_time", DateUtils.timeToStamp(DateUtils.getDate() + " 23:23:59"));
        params.put("search_level", 3);
        JSONObject pageInfo = new JSONObject();
        pageInfo.put("page", 1);
        pageInfo.put("page_size", 2000);
        param.put("page_info", pageInfo);
        param.put("param", params);
        JSONObject apiResult = APIUtil.getApiResult(KuaishouAPIConstant.AD_SEARCH, token, param);
        if (apiResult.getInteger("code") == 0) {
            apiResult = apiResult.getJSONObject("data");
            JSONArray data = apiResult.getJSONArray("data");
            List<KuaishouLiveCreativeList> list = new ArrayList<>();
            for (int i = 0; i < data.size(); i++) {
                JSONObject object = data.getJSONObject(i);
                KuaishouLiveCreativeList accountReport = JSONObject.parseObject(object.toJSONString(), KuaishouLiveCreativeList.class);
                accountReport.setAccountId(accountId);
                accountReport.setReportDate(Long.valueOf(object.getString("report_date").replace("-", "")));
                accountReport.setCreativeCreateTime(Long.valueOf(DateUtils.timestampToStr(object.getLong("creative_create_time"))));
                list.add(accountReport);
            }
            if (!Check.isNull(list)) {
                mapper.replaceBatch(list);
            }
        } else {
            log.error("获取直播账户报表，账户{}，{}", accountId, apiResult.toJSONString());
        }
        return result.success("success");
    }
}
