package cn.com.ctop.job.live.service.impl;

import cn.com.ctop.job.live.entity.KuaishouLiveCreativeReportDaily;
import cn.com.ctop.job.live.mapper.KuaishouLiveCreativeReportDailyMapper;
import cn.com.ctop.job.live.service.IKuaishouLiveCreativeReportDailyService;
import cn.com.ctop.job.live.utils.APIUtil;
import cn.com.ctop.job.live.utils.Check;
import cn.com.ctop.job.live.utils.DateUtils;
import cn.com.ctop.job.live.utils.KuaishouAPIConstant;
import cn.com.ctop.job.live.utils.Result;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 直播创意报Service业务层处理
 *
 * @author ruoyi
 * @date 2022-07-19
 */
@Slf4j
@Service
public class KuaishouLiveCreativeReportDailyServiceImpl implements IKuaishouLiveCreativeReportDailyService {

    @Autowired
    private KuaishouLiveCreativeReportDailyMapper mapper;

    @Override
    public Result<Object> getKuaishouCreativeReport(Long accountId, String token, int page) {
        log.info("调用接口---getKuaishouAccountReport(获取直播创意报表)---账户:{} ===第{}页===", accountId, page);
        Result<Object> result = new Result<>();
        Map<String, Object> param = new HashMap<String, Object>();
        param.put("advertiser_id", accountId);
        JSONObject params = new JSONObject();
        String yesterday = DateUtils.getSubtractTime(new Date(), 1);
//        String yesterday = "2022-06-14";
        params.put("start_time", DateUtils.timeToStamp(yesterday + " 00:00:00"));
        params.put("end_time", DateUtils.timeToStamp(yesterday + " 23:23:59"));
        params.put("view_type", 4);
        params.put("group_type", 1);
        JSONObject pageInfo = new JSONObject();
        pageInfo.put("page", 1);
        pageInfo.put("page_size", 2000);
        param.put("page_info", pageInfo);
        param.put("param", params);
        JSONObject apiResult = APIUtil.getApiResult(KuaishouAPIConstant.REPORT_LIST, token, param);
        if (apiResult.getInteger("code") == 0) {
            apiResult = apiResult.getJSONObject("data");
            JSONArray data = apiResult.getJSONArray("data");
            List<KuaishouLiveCreativeReportDaily> list = new ArrayList<>();
            for (int i = 0; i < data.size(); i++) {
                JSONObject object = data.getJSONObject(i);
                KuaishouLiveCreativeReportDaily creativeReport = JSONObject.parseObject(object.toJSONString(), KuaishouLiveCreativeReportDaily.class);
                creativeReport.setAccountId(accountId);
                creativeReport.setReportDate(Long.valueOf(DateUtils.timestampToStr(object.getLong("report_date"))));
                list.add(creativeReport);
            }
            if (!Check.isNull(list)) {
                mapper.replaceBatch(list);
            }
        } else {
            log.error("获取直播创意报表，账户{}，{}", accountId, apiResult.toJSONString());
        }
        return result.success("success");
    }
}
