package cn.com.ctop.job.live.utils;

import com.alibaba.fastjson.JSONObject;
import com.google.gson.Gson;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.HttpStatus;
import org.apache.http.client.CookieStore;
import org.apache.http.client.HttpClient;
import org.apache.http.client.config.CookieSpecs;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
import org.apache.http.conn.ssl.TrustStrategy;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.BasicCookieStore;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.ssl.SSLContextBuilder;
import org.apache.http.util.EntityUtils;

import javax.net.ssl.SSLContext;
import java.nio.charset.Charset;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

@Slf4j
public class HttpUtils {

  public static CookieStore COOKIESTORE = new BasicCookieStore();
  /** setProxy(new HttpHost("106.125.239.179", 4245)) */
  public static Map<String, Map<String, String>> fontsMap = new HashMap<>();

  public static String USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.100 Safari/537.36";

  public static CloseableHttpClient createSslClientDefault() {
    try {
      SSLContext sslContext =
          new SSLContextBuilder()
              .loadTrustMaterial(
                  null,
                  new TrustStrategy() {
                    // 信任所有证书
                    @Override
                    public boolean isTrusted(X509Certificate[] chain, String authType)
                        throws CertificateException {
                      return true;
                    }
                  })
              .build();
      RequestConfig globalConfig =
          RequestConfig.custom()
              .setConnectTimeout(30000)
              .setSocketTimeout(30000)
              .setCookieSpec(CookieSpecs.STANDARD)
              .build();
      SSLConnectionSocketFactory sslFactory = new SSLConnectionSocketFactory(sslContext);
      return HttpClients.custom()
          .setDefaultCookieStore(COOKIESTORE)
          .setDefaultRequestConfig(globalConfig)
          .setConnectionReuseStrategy((response, context) -> false)
          .setSSLSocketFactory(sslFactory)
          .build();
    } catch (Exception e) {
      log.error("处理Https证书异常", e);
    }
    return HttpClients.createDefault();
  }

  public static String httpPostRequest(String url, Map<String, Object> param, Map<String, String> headers) {
    HttpClient httpClient = createSslClientDefault();
    String strReturn = "";
    try {
      HttpPost httppost = new HttpPost(url);
      httppost.setHeader("User-Agent", USER_AGENT);
      httppost.addHeader("Content-Type", "application/json");
      if (headers != null && headers.size() > 0) {
        for (String key : headers.keySet()) {
          httppost.setHeader(key, headers.get(key));
        }
      }
      if (param != null && param.size() > 0) {
        httppost.setEntity(new StringEntity(new Gson().toJson(param), Charset.forName("UTF-8")));
      }
      RequestConfig requestConfig = RequestConfig.custom().setSocketTimeout(300 * 1000).setConnectTimeout(300 * 1000).build();
      httppost.setConfig(requestConfig);
      HttpEntity respentity;

      HttpResponse response = httpClient.execute(httppost);
      int statusCode = response.getStatusLine().getStatusCode();
      if (statusCode == HttpStatus.SC_MOVED_PERMANENTLY || statusCode == HttpStatus.SC_MOVED_TEMPORARILY) {
        String newUrl = response.getFirstHeader("Location").getValue();
        return httpPostRequest(newUrl, param, headers);
      } else if (statusCode == HttpStatus.SC_OK) {
        respentity = response.getEntity();
        strReturn = EntityUtils.toString(respentity);
        return strReturn;
      }
    } catch (Exception e) {
      e.printStackTrace();
      log.error(e.getMessage());
    }
    return strReturn;
  }


  public static String httpGetRequest(String url, Map<String, String> headers, JSONObject params) {
    HttpClient httpClient = createSslClientDefault();
    String strReturn = "";
    try {
      HttpGetWithBodyEntity httpGet = new HttpGetWithBodyEntity(url);
      if (headers != null) {
        Iterator<String> keyIter = headers.keySet().iterator();
        while (keyIter.hasNext()) {
          String curKey = keyIter.next();
          if (curKey != null && headers.get(curKey) != null) {
            httpGet.addHeader(curKey, headers.get(curKey));
          }
        }
      }
      httpGet.setEntity(new StringEntity(params.toJSONString(), Charset.forName("UTF-8")));
      HttpEntity respentity;
      HttpResponse response = httpClient.execute(httpGet);
      respentity = response.getEntity();
      strReturn = EntityUtils.toString(respentity);
    } catch (Exception e) {
      e.printStackTrace();
      log.error(e.getMessage());
    }
    return strReturn;
  }

}
